Coverage for setup.py: 0%

# Coverage for setup.py : 0%

## 7 statements 0 run 7 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# -*- coding: utf-8 -*-

2 from distutils.core import setup

3 from setuptools import find_packages # type: ignore

4

5

6 def parse_requirements(filename, session=False):

7 """ load requirements from a pip requirements file """

8 lineiter = (line.strip() for line in open(filename))

9 return [line for line in lineiter if line and not line.startswith("#")]

10

11

12 install_requires = parse_requirements('requirements.txt', session=False)

13

14 setup(

15 name='django-jutil',

16 version='3.3.5',

17 author=u'Jani Kajala',

18 author_email='kajala@gmail.com',

19 packages=find_packages(exclude=['project', 'venv']),

20 include_package_data=True,

21 url='https://github.com/kajala/django-jutil',

22 license='MIT licence, see LICENCE.txt',

23 description='Collection of small utilities for Django and Django REST framework projects',

24 long_description=open('README.md').read(),

25 zip_safe=False,

26 install_requires=install_requires

27)